# Fact Sheet Mapping Between ServiceNow and SAP LeanIX
### On this page
  * [Configuring a Fact Sheet Mapping](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#configuring-a-fact-sheet-mapping)
  * [Fact Sheet Mapping Parameters](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#fact-sheet-mapping-parameters)
  * [Configuring Field Mappings](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#configuring-field-mappings)
  * [Field Mapping Parameters](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#field-mapping-parameters)
  * [AI-Generated Field Mapping Suggestions](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#ai-generated-field-mapping-suggestions)
  * [Mapping Type](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#mapping-type)
  * [Additional Configuration Details](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#additional-configuration-details)
  * [Synchronization Filters](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix#synchronization-filters)


View all
Configure mappings between specific fields in SAP LeanIX fact sheets and ServiceNow tables.
